"use strict";jQuery,jQuery(document).ready(function(o){0<o(".offset-side-bar").length&&o(".offset-side-bar").on("click",function(e){e.preventDefault(),e.stopPropagation(),o(".cart-group").addClass("isActive")}),0<o(".close-side-widget").length&&o(".close-side-widget").on("click",function(e){e.preventDefault(),o(".cart-group").removeClass("isActive")}),0<o(".navSidebar-button").length&&o(".navSidebar-button").on("click",function(e){e.preventDefault(),e.stopPropagation(),o(".info-group").addClass("isActive")}),0<o(".close-side-widget").length&&o(".close-side-widget").on("click",function(e){e.preventDefault(),o(".info-group").removeClass("isActive")}),o("body").on("click",function(e){o(".info-group").removeClass("isActive"),o(".cart-group").removeClass("isActive")}),o(".xs-sidebar-widget").on("click",function(e){e.stopPropagation()}),0<o(".xs-modal-popup").length&&o(".xs-modal-popup").magnificPopup({type:"inline",fixedContentPos:!1,fixedBgPos:!0,overflowY:"auto",closeBtnInside:!1,callbacks:{beforeOpen:function(){this.st.mainClass="my-mfp-slide-bottom xs-promo-popup"}}})});